.. PyNeuroML documentation master file, created by
   sphinx-quickstart on Mon Jul  5 11:08:00 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PyNeuroML's documentation!
=====================================

Welcome to the pyNeuroML documentation.
Here you will find information on installing, using, and contributing to pyNeuroML.
For more information on NeuroML standard, other tools in the NeuroML ecosystem, the NeuroML community and how to get in touch with us, please see the documentation at https://docs.neuroml.org.


Contents
---------

.. toctree::
   :maxdepth: 1

   introduction
   pyneuroml

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
